.. mongo-mockup-db documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

MockupDB
========

.. image:: _static/mask.jpg

Mock server for testing MongoDB clients and creating `MongoDB Wire Protocol`_
servers.

The :doc:`tutorial` is the primary documentation.

Contents:

.. toctree::
   :maxdepth: 1

   readme
   installation
   tutorial
   reference
   contributing
   authors
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Image Credit: `gnuckx <https://www.flickr.com/photos/34409164@N06/4708707234/>`_

.. _MongoDB Wire Protocol: http://docs.mongodb.org/meta-driver/latest/legacy/mongodb-wire-protocol/
